Class: Pgbus::Metrics::Backend::Null

Inherits:
Backend
  • Object
show all
Defined in:
lib/pgbus/metrics/backend.rb

Overview

No-op backend. Used as the resolved backend for a nil configuration so callers never have to nil-check, though in practice the Subscriber is simply not installed when metrics_backend is nil.

Instance Method Summary collapse

Instance Method Details

#gauge(_name, _value, _tags = {}) ⇒ Object



33
# File 'lib/pgbus/metrics/backend.rb', line 33

def gauge(_name, _value, _tags = {}) = nil

#histogram(_name, _value, _tags = {}) ⇒ Object



34
# File 'lib/pgbus/metrics/backend.rb', line 34

def histogram(_name, _value, _tags = {}) = nil

#increment(_name, _value = 1, _tags = {}) ⇒ Object



32
# File 'lib/pgbus/metrics/backend.rb', line 32

def increment(_name, _value = 1, _tags = {}) = nil