Class: Pgbus::Process::Dispatcher::MaintenanceResult
- Inherits:
-
Struct
- Object
- Struct
- Pgbus::Process::Dispatcher::MaintenanceResult
- Defined in:
- lib/pgbus/process/dispatcher.rb
Overview
Outcome of a single maintenance task in a cycle. Lets run_maintenance distinguish success/failed/skipped and, on failure, carry the error and task name for reporting or summarizing.
Instance Attribute Summary collapse
-
#error ⇒ Object
Returns the value of attribute error.
-
#status ⇒ Object
Returns the value of attribute status.
-
#task ⇒ Object
Returns the value of attribute task.
Instance Method Summary collapse
Instance Attribute Details
#error ⇒ Object
Returns the value of attribute error
62 63 64 |
# File 'lib/pgbus/process/dispatcher.rb', line 62 def error @error end |
#status ⇒ Object
Returns the value of attribute status
62 63 64 |
# File 'lib/pgbus/process/dispatcher.rb', line 62 def status @status end |
#task ⇒ Object
Returns the value of attribute task
62 63 64 |
# File 'lib/pgbus/process/dispatcher.rb', line 62 def task @task end |
Instance Method Details
#skipped? ⇒ Boolean
64 |
# File 'lib/pgbus/process/dispatcher.rb', line 64 def skipped? = status == :skipped |
#success? ⇒ Boolean
63 |
# File 'lib/pgbus/process/dispatcher.rb', line 63 def success? = status == :success |